==> provider_software_2.6.1.tar.gz: provider_software_2.6.1/archive/archive.py <==
#!C:\Python25\python.exe

import shutil
import time, datetime
from xml.dom.minidom import Document
import os, sys, zipfile, os.path
import xml.dom.minidom
from xml.dom.minidom import Node
import xml.sax
import pprint
import urllib2, urllib
import time, datetime

def log(message, mode="a"):
	global logFile
	s = datetime.datetime.now().ctime() + " | " + message
	l = open(logFile, mode)
	l.write(s.encode("utf-8")+"\n")
	l.close()
	print(s)


archiveFilename = sys.argv[1]
_dsa = sys.argv[2]

path = os.path.dirname( __file__ )+os.sep+_dsa+os.sep
if not os.path.exists(path):
	os.makedirs(path)
	
logFile = path+archiveFilename+".log"

log("archiveFile=" + path+archiveFilename, "w")

sys.stderr = sys.stdout


queryFile = path+archiveFilename + ".query.xml"
configFile = path+archiveFilename + ".config.xml"
dom = xml.dom.minidom.parse(configFile)
dsa = str(dom.getElementsByTagName("dsa")[0].firstChild.data)
url = str(dom.getElementsByTagName("wrapperurl")[0].firstChild.data)
ticket = str(dom.getElementsByTagName("ticket")[0].firstChild.data)
maxErrors = int(dom.getElementsByTagName("consecutiveerrors")[0].firstChild.data)

#
procFilename = path+archiveFilename + ".proc"
proc = open(procFilename, "w")
proc.write("Pid: "+str(os.getpid()))
proc.write("Process started "+datetime.datetime.now().ctime())
proc.close()

log("queryFile="+queryFile)
log("configFile="+configFile)
log("dsa="+dsa)
log("url="+url)
log("ticket="+ticket)


dom = xml.dom.minidom.parse(queryFile)
n = dom.getElementsByTagName("responseFormat")[0]
#schema = n.firstChild.data
limit = int(n.getAttribute("limit"))

#log("schema="+schema)
#log("limit="+limit)


firstrun = 1
consecutiveErrors = 0;
archiveAppend = "0"

endMessage = ""

while True:

	try:
		# check if cancel
		proc = open(procFilename)
		cancel = proc.read()
		proc.close()
		if cancel == "cancel":
			log("Cancel received.")
			break;
		
		start = int(n.getAttribute("start"))		
		queryData = dom.toxml('utf-8')
		log("Requesting archiving of records " + str(start+1) + " to " + str(start + limit + 1))


		data = urllib.urlencode([('query', queryData)])
		req = urllib2.Request(url + "&archiverequest=1&archiveappend="+archiveAppend+"&archivefilename="+archiveFilename+"&ticket="+ticket)
		fd = urllib2.urlopen(req, data)

		#log("Query data: " + queryData)

		data = fd.read()
		fd.close()

		#log("data: " + data)

		r = xml.dom.minidom.parseString(data.encode("utf-8"))
		r.documentElement.tagName == "response"
		#log(logFile, r.toxml())

		hits = 0
		status = "N/A"
		message = "N/A"
		try:
			hits = int(r.getElementsByTagName("hits")[0].firstChild.data)
			status = str(r.getElementsByTagName("status")[0].firstChild.data)
			message = str(r.getElementsByTagName("message")[0].firstChild.data)
		except:
			pass

		fetched = hits - start - 1

		log("" + str(fetched) + " records archived")
		#log("  hits   : "+str(hits))
		log("  status : "+status)
		log("  message: "+message)

		if status != "ok":
			consecutiveErrors += 1
			if endMessage == "":
				endMessage = "---------------- Error Summary --------------------\n"
				endMessage += "One or several errors occured during the archiving process:\n"
			endMessage += "ERROR: An error occured while requesting records "+str(start+1)+" through "+str(start + limit)+":\nStatus:"+status+"\nMessage:"+message+"\n"
			log("ERROR: An error occured during this request")
			if consecutiveErrors >= maxErrors:
				log(str(maxErrors)+" consecutive errors, giving up further tries. Exit.")
				break;
		else:
			consecutiveErrors = 0

		if fetched == 0 and status == "ok":
			log("Archiving has finished!")
			break;
		if fetched <= limit -1:
			if firstrun == 1 and status == "ok":
				if fetched < 1:
					fetched = 1
				log("Adjusting fetch size limit to " + str(fetched))
				limit = fetched;
				#start = fetched
			elif status == "ok":
				log("Archiving has finished!")
				break;
		
		n.removeAttribute("start")
		n.setAttribute("start", str(start + limit + 1))
		archiveAppend = "1"

		firstrun = 0



		
	except:
		n.removeAttribute("start")
		n.setAttribute("start", str(start + limit))
		archiveAppend = "1"

		
		error = str(sys.exc_info()[0]) + "," + str(sys.exc_info()[1]) + "," + str(sys.exc_info()[2]) + "\n"
		if endMessage == "":
			endMessage = "One or several errors occured during the archiving process:\n"+error
		endMessage += "ERROR: An error occured while requesting records "+str(start+1)+" through "+str(start + limit)+":\n"+error
		#log("ERROR: An error occured during this request: "+error+"\ndata:\n"+data)
		log("ERROR: An error occured during this request: "+error+"\n")
		consecutiveErrors += 1
		if consecutiveErrors >= maxErrors:
			log(str(maxErrors)+" consecutive errors, giving up further tries. Exit.")
			break;
		

log("Removing proc file.")
log(endMessage)

if cancel != "cancel":
	try:
		_path = ".."+os.sep+".."+os.sep+"www"+os.sep+"downloads"+os.sep+dsa
		if not os.path.exists(_path):
			os.makedirs(_path)
		shutil.move(path+archiveFilename, ".."+os.sep+".."+os.sep+"www"+os.sep+"downloads"+os.sep+dsa+os.sep+archiveFilename)
	except:
		error = str(sys.exc_info()[0]) + "," + str(sys.exc_info()[1]) + "," + str(sys.exc_info()[2]) + "\n"
		log(error)
		pass

os.remove(procFilename)

if cancel == "cancel":	
	try:	
		shutil.move(configFile, configFile + ".bak")
		log("Renaming archive configuration file to "+configFile + ".bak")
	except:
		pass

	
	

log("EXIT")

==> provider_software_3.0.1.tar.gz: provider_software_3.0.1/archive/archive.py <==
import shutil
import time, datetime
from xml.dom.minidom import Document
import os, sys, zipfile, os.path
import xml.dom.minidom
from xml.dom.minidom import Node
import xml.sax
import pprint
import urllib2, urllib
import time, datetime
import traceback

def log(message, mode="a"):
	global logFile
	s = datetime.datetime.now().ctime() + " | " + message
	l = open(logFile, mode)
	l.write(s.encode("utf-8")+"\n")
	l.close()
	print(s)


archiveFilename = sys.argv[1]
_dsa = sys.argv[2]

path = os.path.dirname( __file__ )+os.sep+_dsa+os.sep
if not os.path.exists(path):
	os.makedirs(path)
	
logFile = path+archiveFilename+".log"

log("archiveFile=" + path+archiveFilename, "w")

sys.stderr = sys.stdout


queryFile = path+archiveFilename + ".query.xml"
configFile = path+archiveFilename + ".config.xml"
dom = xml.dom.minidom.parse(configFile)
dsa = str(dom.getElementsByTagName("dsa")[0].firstChild.data)
url = str(dom.getElementsByTagName("wrapperurl")[0].firstChild.data)
ticket = str(dom.getElementsByTagName("ticket")[0].firstChild.data)
download_folder = os.path.join(str(dom.getElementsByTagName("downloadfolder")[0].firstChild.data), dsa)
maxErrors = int(dom.getElementsByTagName("consecutiveerrors")[0].firstChild.data)

procFilename = path+archiveFilename + ".proc"
proc = open(procFilename, "w")
proc.write("Pid: "+str(os.getpid()))
proc.write("Process started "+datetime.datetime.now().ctime())
proc.close()

log("queryFile="+queryFile)
log("configFile="+configFile)
log("dsa="+dsa)
log("downloadFolder="+ download_folder)
log("url="+url)
log("ticket="+ticket)

dom = xml.dom.minidom.parse(queryFile)
n = dom.getElementsByTagName("responseFormat")[0]
limit = int(n.getAttribute("limit"))
log("limit="+str(limit))

firstrun = 1
consecutiveErrors = 0;
archiveAppend = "0"
endMessage = ""

while True:
	
	try:
		# check if cancel
		proc = open(procFilename)
		cancel = proc.read()
		proc.close()
		if cancel == "cancel":
			log("Cancel received.")
			break;
		
		start = int(n.getAttribute("start"))		
		queryData = dom.toxml('utf-8')
		log("Requesting archiving of records " + str(start+1) + " to " + str(start + limit))

		data = urllib.urlencode([('query', queryData)])
		req = urllib2.Request(url + "&archiverequest=1&archiveappend="+archiveAppend+"&archivefilename="+archiveFilename+"&ticket="+ticket)
		fd = urllib2.urlopen(req, data)

		#log("Query data: " + queryData)

		data = fd.read()
		fd.close()
		
		#log("data: " + data)

		r = xml.dom.minidom.parseString(data.encode("utf-8"))
		r.documentElement.tagName == "response"
		#log(logFile, r.toxml())

		hits = 0
		rcount = 0
		dropped = 0
		status = "N/A"
		message = "N/A"
		try:
			hits = int(r.getElementsByTagName("hits")[0].firstChild.data)
			rcount = int(r.getElementsByTagName("rcount")[0].firstChild.data)
			dropped = int(r.getElementsByTagName("dropped")[0].firstChild.data)
			status = str(r.getElementsByTagName("status")[0].firstChild.data)
			message = str(r.getElementsByTagName("message")[0].firstChild.data)
		except:
			pass

		fetched = hits - start
		
		log("  hits    : "+str(hits))
		log("  rcount  : "+str(rcount))
		log("  dropped : "+str(dropped))
		log("  status  : "+status)
		log("  message : "+message)

		if status != "ok":
			consecutiveErrors += 1
			if endMessage == "":
				endMessage = "---------------- Error Summary --------------------\n"
				endMessage += "One or several errors occurred during the archiving process:\n"
			endMessage += "ERROR: An error occurred while requesting records "+str(start+1)+" through "+str(start + limit)+":\nStatus:"+status+"\nMessage:"+message+"\n"
			log("ERROR: An error occurred during this request")
			if consecutiveErrors >= maxErrors:
				log(str(maxErrors)+" consecutive errors, giving up further tries. Exit.")
				break;
		else:
			consecutiveErrors = 0

		if rcount + dropped == 0 and status == "ok":
			log("Archiving has finished!")
			break;

		if rcount + dropped == hits and status == "ok":
			log("Archiving has finished!")
			break;

		if rcount + dropped  < limit:
			if firstrun == 1 and status == "ok":				
				log("Adjusting fetch size limit to " + str(rcount))
				limit = rcount;
				#start = fetched
			elif status == "ok":
				log("Archiving has finished!")
				break;
				
		nextStart = start + limit
		n.removeAttribute("start")
		n.setAttribute("start", str(nextStart))
		archiveAppend = "1"

		firstrun = 0



		
	except:
		n.removeAttribute("start")
		n.setAttribute("start", str(start + limit))
		archiveAppend = "1"

		et, ev, tb = sys.exc_info()
		error = str(sys.exc_info()[1])
		while tb :
			co = tb.tb_frame.f_code
			filename = "Filename = " + str(co.co_filename)
			line_no =  "Error Line # = " + str(traceback.tb_lineno(tb))
			error += "\n" + filename
			error += "\n" + line_no
			tb = tb.tb_next
		error += "\n"

		if endMessage == "":
			endMessage = "One or several errors occurred during the archiving process:\n"+error
		endMessage += "ERROR: An error occurred while requesting records "+str(start+1)+" through "+str(start + limit)+":\n"+error
		log("ERROR: An error occurred during this request: "+error+"\n")
		consecutiveErrors += 1
		if consecutiveErrors >= maxErrors:
			log(str(maxErrors)+" consecutive errors, giving up further tries. Exit.")
			break;
		
log("Removing proc file.")
log(endMessage)

downloadfile = os.path.join(download_folder, archiveFilename)
if cancel != "cancel" and consecutiveErrors < maxErrors:
	try:
		if not os.path.exists(download_folder):
			os.makedirs(download_folder)
		shutil.move(path + archiveFilename, downloadfile)
	except:
		error = str(sys.exc_info()[0]) + "," + str(sys.exc_info()[1]) + "," + str(sys.exc_info()[2]) + "\n"
		log(error)
		pass

os.remove(procFilename)

if cancel == "cancel" or consecutiveErrors >= maxErrors:
	if not os.path.exists(downloadfile):
		try:
			shutil.move(configFile, configFile + ".bak")
			log("Renaming archive configuration file to "+configFile + ".bak")
		except:
			pass

	
	

log("EXIT")
